@@ -8,10 +8,9 @@ package My::Envoy::Base;
     with 'Model::Envoy' => { storage => {
         'DBIC' => {
             schema => sub {
-                $schema ||= My::DB->db_connect('/tmp/envoy');
+                $schema ||= My::DB->db_connect();
             }
-        },
-        'Memory' => {},
+        }
     } };
 
 1;
\ No newline at end of file
